require 'tempfile'
require 'fileutils'
require 'active_support/core_ext/string/inflections'
        
module Pod
    class Command
        class Repo < Command
            class Bump < Repo
                self.summary = 'Bump the version number'

                self.description = <<-DESC
                Validates `NAME.podspec` or `*.podspec` in the current working dir
                `pod repo bump 0.1.0`
                DESC

                self.arguments = [
                    CLAide::Argument.new('NAME.podspec', false),
                ]

                def self.options
                    [].concat(super)
                end

                def initialize(argv)
                    @tag_version = argv.shift_argument
                    super
                end

                def validate!
                    super
                    help! 'A bump version is required.' unless @tag_version
                    unless @tag_version
                        raise Informative,
                            "A bump version is required." \
                            '`pod repo bump 0.1.0`.'
                    end
                end

                def run
                    podspec_files.each do |spec_file|
                        spec = Pod::Specification.from_file(spec_file)
                        if @tag_version.to_s != spec.version.to_s
                            modify_podspec(spec_file, @tag_version)
                        else 
                            UI.puts " - [No change] #{spec.name}: #{@tag_version}"
                        end
                    end
                end

                def modify_podspec(path, version)
                    unless version =~ /^(\d+\.)?(\d+\.)?(\*|\d+)$/
                        UI.puts "Invalid version #{version}"
                        return 
                    end
                    
                    unless File.exist?path
                        UI.puts "Podspec file not found"
                        return
                    end
            
                    File.open(path, "r+") do |f|
                        s = ""
                        f.each_line do |line|
                            if line.to_s =~ /s\.version\s*=\s*'(\d+\.)?(\d+\.)?(\*|\d+)'/
                                line = line.sub(/(\d+\.)?(\d+\.)?(\*|\d+)/) do |match| 
                                    version.to_s
                                end
                            end
                            if line.to_s =~ /s\.version\s*=\s*"(\d+\.)?(\d+\.)?(\*|\d+)"/
                                line = line.sub(/(\d+\.)?(\d+\.)?(\*|\d+)/) do |match| 
                                    version.to_s
                                end
                            end
                            s += line
                        end
                        File.open(path, "w+") do |f| f.write(s) end
                    end	
                end

                # @return [Array<Pathname>] The path of the specifications to push.
                #
                # def podspec_files
                #     if @podspec
                #         path = Pathname(@podspec)
                #         raise Informative, "Couldn't find #{@podspec}" unless path.exist?
                #         [path]
                #     else
                #         files = Pathname.glob('**/*.podspec')
                #         raise Informative, "Couldn't find any podspec files in current directory" if files.empty?
                #         files
                #     end
                # end

                def podspec_files
                    files = Pathname.glob('**/*.podspec')
                    raise Informative, "Couldn't find any podspec files in current directory" if files.empty?
                    files
                end

                #---------------------------------------------------------------------#
            end
        end
    end
end